<?php

if (is_null(theme_get_setting('citynews_style'))) {
  global $theme_key;
  $defaults = array(
    'citynews_style' => 'citynews_black',
	'headbackground' => '',
  );
  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge(theme_get_settings($theme_key), $defaults)
  );
  theme_get_setting('', TRUE);
}

drupal_add_css(drupal_get_path('theme', 'citynews') . '/css/' . get_citynews_style() . '.css', 'theme');

function get_citynews_style() {
  $style = theme_get_setting('citynews_style');
  if (!$style)
  {
    $style = 'citynews_black';
  }
  if (isset($_COOKIE["citynewsstyle"])) {
    $style = $_COOKIE["citynewsstyle"];
  }
  return $style;
}

function citynews_four_colunm($left, $content, $right, $right_2, $right_top_box, $right_bottom_box){
  return $content && $left && ((($right_top_box || $right_bottom_box) && ($right_2 && $right)) || (($right_top_box || $right_bottom_box) && !($right_2 || $right)));
}

function citynews_col_width($left, $content, $right, $right_2, $right_top_box, $right_bottom_box) {
  if (citynews_four_colunm($left, $content, $right, $right_2, $right_top_box, $right_bottom_box)) {
    $class = 'width-18-350'; //if 4 col, content will be 350px
  }
  else {
    if (($content && $left && $right) or ($content && $right && $right_2) or ($content && $left && $right_2)) {
      $class = 'width-28-550'; //if 3 col content will be 550px
    }
    else {
      if (($content && $left) or ($content && $right_2) or ($content && $right)) {
        $class = 'width-38-750'; //if 2 col content will be 750px
      }
      else {
        if ($content != '') {
          $class = 'width-48-950'; //if 1 col content will be 950px
        }
      }
    }
  }
  if (isset($class)) {
    print $class;
  }
}

function citynews_preprocess_page(&$vars, $hook) {
  global $theme;
  
  if ($vars['help'] == "<div class=\"help\"><p></p>\n</div>") {
    $vars['help'] = '';
  }
  
  $body_class = array($vars['body_class']);
    if ($vars['content']) {
    $body_class[] = $vars['is_front'] ? 'front' : 'not-front';
    $body_class[] = $vars['logged_in'] ? 'logged-in' : 'not-logged-in';
    }
    if (isset($vars['node']) && $vars['node']->type) {
      $body_class[] = 'node-type-'. citynews_id_safe($vars['node']->type);
    }
    if (!$vars['is_front']) {
    $path = drupal_get_path_alias($_GET['q']);
    list($section, ) = explode('/', $path, 2);
    $body_class[] = citynews_id_safe('page-'. $path);
    $body_class[] = citynews_id_safe('section-'. $section);
    if (arg(0) == 'node') {
      if (arg(1) == 'add') {
        if ($section == 'node') {
          array_pop($body_class); // Remove 'section-node'
        }
        $body_class[] = 'section-node-add'; // Add 'section-node-add'
      }
      elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
        if ($section == 'node') {
          array_pop($body_class); // Remove 'section-node'
        }
        $body_class[] = 'section-node-'. arg(2); // Add 'section-node-edit' or 'section-node-delete'
      }
    }
  }
  
  if ($vars['title']) {
    if (arg(0) == 'taxonomy' && arg(1)=='term' && is_numeric(arg(2))) {
      $vars['title'] = '<h1 class="title category"><span>Category:</span> <em>'. $vars['title'] .'</em>'. $vars['feed_icons'] .'</h1>';
    }
    else {
      $vars['title'] = '<h1 class="title">'. $vars['title'] .'</h1>';
    }
  }
  
  if ($vars['is_front']) {
    if ($vars['logo']) {
      $vars['logo'] = '<h1 class="brand"><a href="'. $vars['front_page'] .'" title="'. $vars['site_name'] .'"><img src="'. $vars['logo'] .'" alt="'. $vars['site_name'] .'" /></a></h1>'; 
    }
    elseif ($vars['site_name']) {
      $vars['site_name'] = '<h1 class="brand"><a href="'. $vars['front_page'] .'" title="'. $vars['site_name'] .'">'. $vars['site_name'] .'</a></h1>'; 
    }
  }
  else {
    if ($vars['logo']) {
      $vars['logo'] = '<div class="brand"><a href="'. $vars['front_page'] .'" title="'. $vars['site_name'] .'"><img src="'. $vars['logo'] .'" alt="'. $vars['site_name'] .'" /></a></div>'; 
    }
    elseif ($vars['site_name']) {
      $vars['site_name'] = '<div class="brand"><a href="'. $vars['front_page'] .'" title="'. $vars['site_name'] .'">'. $vars['site_name'] .'</a></div>'; 
    }
  }
  
  $vars['closure'] .= '<span class="developer">
<strong><a href="http://www.yunet.ru/book/temy-dlya-drupala-opisanie-primenenie" title="Drupal temes on www.yunet.ru">Drupal theme</a></strong> by <a href="http://www.yunet.ru" title="Go to www.yunet.ru">www.yunet.ru</a></span>';
  $vars['body_class'] = implode(' ', $body_class); // Concatenate with spaces
  $vars['primary_links_tree'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
  $vars['headbgr'] = '/'.theme_get_setting('headbackground');
}

function citynews_preprocess_node(&$vars, $hook) {
  global $user;


  $node_classes = array();
  if ($vars['sticky']) {
    $node_classes[] = 'sticky';
  }
  if (!$vars['node']->status) {
    $node_classes[] = 'node-unpublished';
    $vars['unpublished'] = TRUE;
  }
  else {
    $vars['unpublished'] = FALSE;
  }
  if ($vars['node']->uid && $vars['node']->uid == $user->uid) {
    $node_classes[] = 'node-mine';
  }
  if ($vars['teaser']) {
    $node_classes[] = 'node-teaser';
  }
  $node_classes[] = 'node-type-'. $vars['node']->type;
  $vars['node_classes'] = implode(' ', $node_classes); // Concatenate with spaces
}

function citynews_preprocess_block(&$vars, $hook) {
  $block = $vars['block'];
  $block_classes = array();
  $block_classes[] = 'block-'. $block->module;
  $block_classes[] = 'region-'. $vars['block_zebra'];
  $block_classes[] = $vars['zebra'];
  $block_classes[] = 'region-count-'. $vars['block_id'];
  $block_classes[] = 'count-'. $vars['id'];
  $vars['block_classes'] = implode(' ', $block_classes);

}

function citynews_preprocess_comment(&$vars, $hook) {
  global $user;

  $node = node_load($vars['comment']->nid);
  $vars['author_comment'] = $vars['comment']->uid == $node->uid ? TRUE : FALSE;
  $comment_classes = array();

  static $comment_odd = TRUE;
  $comment_classes[] = $comment_odd ? 'odd' : 'even';
  $comment_odd = !$comment_odd;

  if ($vars['comment']->status == COMMENT_NOT_PUBLISHED) {
    $comment_classes[] = 'comment-unpublished';
    $vars['unpublished'] = TRUE;
  }
  else {
    $vars['unpublished'] = FALSE;
  }
  if ($vars['author_comment']) {
    $comment_classes[] = 'comment-by-author';
  }
  if ($vars['comment']->uid == 0) {
    $comment_classes[] = 'comment-by-anon';
  }
  if ($user->uid && $vars['comment']->uid == $user->uid) {
    $comment_classes[] = 'comment-mine';
  }
  $vars['comment_classes'] = implode(' ', $comment_classes);

  if (variable_get('comment_subject_field', 1) == 0) {
    $vars['title'] = '';
  }
}

function phptemplate_user_picture(&$account) {
  if (variable_get('user_pictures', 0)) {
    if ($account->picture && file_exists($account->picture)) {
      $picture = file_create_url($account->picture);
    }
    else if (variable_get('user_picture_default', '')) {
      $picture = variable_get('user_picture_default', '');
    }
    if (isset($picture)) {
      $alt = t("@user's picture", array('@user' => $account->name ? $account->name : variable_get('anonymous', t('Anonymous'))));
      $picture = theme('image', $picture, $alt, $alt, '', FALSE);
      if (!empty($account->uid) && user_access('access user profiles')) {
        $attributes = array('attributes' => array('title' => t('View user profile.')), 'html' => TRUE);
        $picture ='<div class="picture">'.l($picture, "user/$account->uid", $attributes).'</div>';
      }
      return $picture;
    }
  }
}

function citynews_id_safe($string) {
  $string = strtolower(preg_replace('/[^a-zA-Z0-9_-]+/', '-', $string));
  if (!ctype_lower($string{0})) {
    $string = 'id'. $string;
  }
  return $string;
}
